@@ -1,16 +1,17 @@
 # -*- coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
-import os
 import json
 import logging
+import os
 import re
-
 from datetime import timedelta
-logger = logging.getLogger(__name__)
 
 import gpodder
 from gpodder import util
 
+logger = logging.getLogger(__name__)
+
+
 _ = gpodder.gettext
 
 __title__ = _('Subtitle Downloader for TED Talks')
@@ -47,8 +48,8 @@ class gPodderExtension(object):
         srtContent = ''
         for captionIndex, caption in enumerate(jsonobject['captions'], 1):
             startTime = self.milli_to_srt(introduration + caption['startTime'])
-            endTime = self.milli_to_srt(introduration + caption['startTime'] +
-                                        caption['duration'])
+            endTime = self.milli_to_srt(introduration + caption['startTime']
+                                        + caption['duration'])
             srtContent += ''.join([str(captionIndex), os.linesep, startTime,
                                    ' --> ', endTime, os.linesep,
                                    caption['content'], os.linesep * 2])
@@ -58,8 +59,8 @@ class gPodderExtension(object):
     def get_data_from_url(self, url):
         try:
             response = util.urlopen(url).read()
-        except Exception, e:
-            logger.warn("subtitle url returned error %s", e)
+        except Exception as e:
+            logger.warning("subtitle url returned error %s", e)
             return ''
         return response
 
@@ -92,8 +93,8 @@ class gPodderExtension(object):
             intro = episode_data
             intro = episode_data.split('introDuration":')[1] \
                                 .split(',')[0] or INTRO_DEFAULT
-            intro = int(float(intro)*1000)
-        except (ValueError, IndexError), e:
+            intro = int(float(intro) * 1000)
+        except (ValueError, IndexError) as e:
             logger.info("Couldn't parse introDuration string: %s", intro)
             intro = INTRO_DEFAULT * 1000
         current_filename = episode.local_filename(create=False)
@@ -103,11 +104,10 @@ class gPodderExtension(object):
         try:
             with open(srt_filename, 'w+') as srtFile:
                 srtFile.write(sub.encode("utf-8"))
-        except Exception, e:
-            logger.warn("Can't write srt file: %s",e)
+        except Exception as e:
+            logger.warning("Can't write srt file: %s", e)
 
     def on_episode_delete(self, episode, filename):
         srt_filename = self.get_srt_filename(filename)
         if os.path.exists(srt_filename):
             os.remove(srt_filename)
-
